@@ -6,6 +6,7 @@ from soil.filesystem import temporary_directory
 from beanstalk import IDENTIFIER
 from beanstalk.decorators import beanstalk_role
 from beanstalk.tasks.utils import load_role_settings as load_beanstalk_settings
+from beanstalk.titles import tool_title
 
 
 @task
@@ -13,6 +14,9 @@ from beanstalk.tasks.utils import load_role_settings as load_beanstalk_settings
 def setup(settings_path=None, **settings_patches):
     """Setup remote base of beanstalk-stack in this server
     """
+    print tool_title('Beanstalk-stack server setup tool')
+    print ''
+
     # Load beanstalk settings
     settings_patches = eval_kwargs(settings_patches)
     beanstalk_settings = load_beanstalk_settings(local_settings_path=settings_path, **settings_patches)
